package metastudio.components;

import java.io.File;

import javax.swing.JFileChooser;

import metastudio.*;
import metastudio.MultiBridge;
import metastudio.utils.ExtensionFilter;
import aterm.ATerm;
import aterm.ATermFactory;

public class FileDialog extends UserInterfacePanel {
    private static final String OPEN = "open";
    private String previousLocation = "";
    
	public FileDialog(ATermFactory factory, MultiBridge bridge) {
        super(factory, bridge);
    }

    public ATerm showFileDialog(ATerm function, String label, String loc, String extension) {
    	String location;

    	if (!loc.equals("")) {
    		location = loc;
    	} else if (previousLocation.equals("")) {
    		location = System.getProperty("user.dir");
    	} else {
    		location = previousLocation;
    	}

    	File file = showFileBrowser(function, label, location, extension, "*" + extension);
    	String result = "";

    	if (file != null) {
    		result = file.getAbsolutePath();
    		
    		String parent = file.getParent();
    		
    		if (parent != null && loc.equals("")) {
    		  previousLocation = file.getParent();
    		}
    		
    		if (function.match(getFactory().parse(OPEN)) == null) {

    			if (!result.endsWith(extension) && result.lastIndexOf('.') == -1) {
    				result += extension;
    			}
    		}
    	}

    	return getFactory().make("file-name(<str>)", result);
    }
    
    private File showFileBrowser(
    		ATerm function, 
        String label,
        String location,
        String extension,
        String desc) {
        JFileChooser chooser = new JFileChooser(location);
        String[] exts = { extension };
        ExtensionFilter filter = new ExtensionFilter(exts, desc);
        chooser.setFileFilter(filter);
        chooser.setToolTipText(label);

        int option;
        
        if (function.match(getFactory().parse(OPEN)) != null) {
          option = chooser.showOpenDialog(this);
        }
        else {
        	option = chooser.showSaveDialog(this);
        }
        if (option == JFileChooser.APPROVE_OPTION) {
            return chooser.getSelectedFile();
        }

        return null;
    }
}

